===============================
dbaas-zabbix
===============================

.. image:: https://badge.fury.io/py/dbaas-zabbix.svg
    :target: http://badge.fury.io/py/dbaas-zabbix
    
.. image:: https://travis-ci.org/globocom/dbaas-zabbix.svg?branch=master
    :target: https://travis-ci.org/globocom/dbaas-zabbix

.. image:: https://coveralls.io/repos/globocom/dbaas-zabbix/badge.svg?branch=master&service=github :target: https://coveralls.io/github/globocom/dbaas-zabbix?branch=master


A Zabbix Integration for DBaaS.

* Free software: BSD license

Documentation
-------------
* TODO

Features
--------

This package provides a simple interface to zabbix and is used by dbaas to provide monitoring for it's databases.
